PreProcessing
=============

.. automodule:: smltk.preprocessing
    :no-members:

.. autosummary::
    :nosignatures:

    smltk.preprocessing.Ntk

Natural Language Tool Kit
-------------------------

.. autosummary::
    :nosignatures:

    smltk.preprocessing.Ntk.get_tokens_cleaned
    smltk.preprocessing.Ntk.get_doc_cleaned
    smltk.preprocessing.Ntk.create_tuples
    smltk.preprocessing.Ntk.create_vocab_from_docs
    smltk.preprocessing.Ntk.create_vocab_from_tuples
    smltk.preprocessing.Ntk.get_stats_vocab
    smltk.preprocessing.Ntk.get_words_top
    smltk.preprocessing.Ntk.get_vocabs_cleaned
    smltk.preprocessing.Ntk.get_ngrams
    smltk.preprocessing.Ntk.create_features_from_docs
    smltk.preprocessing.Ntk.create_features_from_tuples
    smltk.preprocessing.Ntk.create_words_map
    smltk.preprocessing.Ntk.create_words_cloud
    smltk.preprocessing.Ntk.vectorize_docs

Detailed list
-------------

.. autoclass:: smltk.preprocessing.Ntk
    :members:
